@@ -1,5 +1,6 @@
 import logging
 import os
+import re
 
 import click
 from pymobiledevice3.lockdown import LockdownClient
@@ -85,9 +86,19 @@ def format_line(color, pid, syslog_entry, include_label):
 @click.option('-m', '--match', multiple=True, help='match expression')
 @click.option('-mi', '--match-insensitive', multiple=True, help='insensitive match expression')
 @click.option('include_label', '--label', is_flag=True, help='should include label')
-def syslog_live(lockdown: LockdownClient, out, color, pid, match, match_insensitive, include_label):
+@click.option('-e', '--regex', multiple=True, help='filter only lines matching given regex')
+@click.option('-ei', '--insensitive-regex', multiple=True, help='filter only lines matching given regex (insensitive)')
+def syslog_live(lockdown: LockdownClient, out, color, pid, match, match_insensitive, include_label, regex, insensitive_regex):
     """ view live syslog lines """
 
+    match_regex = [re.compile(f'.*({r}).*') for r in regex]
+    match_regex += [re.compile(f'.*({r}).*', re.IGNORECASE) for r in insensitive_regex]
+
+    def replace(m):
+        if len(m.groups()):
+            return line.replace(m.group(1), colored(m.group(1), attrs=['bold', 'underline']))
+        return None
+
     for syslog_entry in OsTraceService(lockdown=lockdown).syslog(pid=pid):
         line = format_line(color, pid, syslog_entry, include_label)
 
@@ -116,6 +127,15 @@ def syslog_live(lockdown: LockdownClient, out, color, pid, match, match_insensit
                         end = start + len(m)
                         line = line[:start] + colored(line[start:end], attrs=['bold', 'underline']) + line[end:]
 
+        if match_regex:
+            skip = True
+            for r in match_regex:
+                if not r.findall(line):
+                    continue
+
+                line = re.sub(r, replace, line)
+                skip = False
+
         if skip:
             continue
 
